@@ -5,13 +5,13 @@ import hashlib
 files = dict({})
 
 def helper(x, grams):
-	with open(x, "r") as ff:
+	with open(x, "r", encoding='utf-8') as ff:
 		files[x] = set()
 		count = 0
 		s = ""
 		for i in ff:
 			try:
-				files[x].add(hashlib.md5(i.encode('latin-1')).hexdigest())
+				files[x].add(hashlib.md5(i.encode('utf-8')).hexdigest())
 			except:
 				print("error of codec in: ", x)
 			s += i
@@ -38,6 +38,17 @@ def antiplagiarism(path="", type=".c", grams=2):
 	else:
 		list(os.listdir(path)).filter(lambda x: type in x).map(lambda x: helper(path + "/" + x, grams))
 	exited = set()
+	#maxim = set()
 	files.map(lambda x: files.filter(lambda m: m[0] != x[0]).next(lambda k: exited.add(x[0])).filter(
 		lambda f: f[0] not in exited).map(lambda u: (x[0], u[0], jaccard(x, u))).map(
-		lambda x: x[0] + " == " + x[1] + " --> " + str(round(x[2] * 100, 2)) + "%").next(lambda x: print(x)))
+		lambda x: x[0].split("/")[-1] + " == " + x[1].split("/")[-1] + " --> " + str(round(x[2] * 100, 2)) + "%").next(lambda x: print(x)))
+	#.next(
+	#	maxim.add([round(x[2] * 100, 2), str(x[0] + " == " + x[1])])
+	#))
+
+	#maxim = list(maxim)
+	#l = sorted(maxim, key=lambda x: x[1])
+
+	#print()
+
+	#.next(lambda x: print(x)))
